import 'package:flutter/cupertino.dart';
import 'package:flutter/material.dart';
import 'package:flutter/services.dart';
import 'package:insta_html_parser/insta_html_parser.dart';

void main() {
  runApp(InstaParserExampleApp());
}

class InstaParserExampleApp extends StatefulWidget {
  InstaParserExampleApp({Key key}) : super(key: key);

  @override
  _InstaParserExampleAppState createState() => _InstaParserExampleAppState();
}

class _InstaParserExampleAppState extends State<InstaParserExampleApp> {
  
  TextEditingController _textEditingController = TextEditingController();
  TextStyle _textStyleBold = TextStyle(fontSize: 16.0, fontWeight: FontWeight.bold);
  TextStyle _textStyleUrl = TextStyle(fontSize: 16.0);

  void rebuild() {
    setState(() {});
  }

  @override
  Widget build(BuildContext context) {
    final key = new GlobalKey<ScaffoldState>();
    List<Widget> _buildPostData(InstaParser profileInstance) {
      List<Widget> _widgetsList = [];
      _widgetsList.add(Text('Profile Url:', style: _textStyleBold));
      _widgetsList.add(Text('${InstaParser.profileInstance.profileUrl}', style: _textStyleUrl,));
      _widgetsList.add(Container(padding: EdgeInsets.only(top: 8.0, bottom: 8.0), child: Divider(height: 0.0, color: Colors.black)));
      for (int i = 0; i < 12; i++) {

        _widgetsList.add(Text('Post ${i+1}:', style: _textStyleBold));
        _widgetsList.add(
          GestureDetector(
            child: Text('${InstaParser.profileInstance.posts[i]['postUrl']}\n', style: _textStyleUrl,),
            onLongPress: () {
              Clipboard.setData(new ClipboardData(text: '${InstaParser.profileInstance.posts[i]['postUrl']}'));
              key.currentState.showSnackBar(SnackBar(content: new Text("Copied post url")));
            },
          )
        );

        _widgetsList.add(Text('SmallPhoto:', style: _textStyleBold));
        _widgetsList.add(
          GestureDetector(
            child: Text('${InstaParser.profileInstance.posts[i]['photoSmallSize']}\n', style: _textStyleUrl,),
            onLongPress: () {
              Clipboard.setData(new ClipboardData(text: '${InstaParser.profileInstance.posts[i]['photoSmallSize']}'));
              key.currentState.showSnackBar(SnackBar(content: new Text("Copied small size photo url")));
            }
          )
        );

        _widgetsList.add(Text('MediumPhoto:', style: _textStyleBold));
        _widgetsList.add(
          GestureDetector(
            child: Text('${InstaParser.profileInstance.posts[i]['photoMediumSize']}\n', style: _textStyleUrl,),
            onLongPress: () {
              Clipboard.setData(new ClipboardData(text: '${InstaParser.profileInstance.posts[i]['photoMediumSize']}'));
              key.currentState.showSnackBar(SnackBar(content: new Text("Copied medium size photo url")));
            }
          )
        );
        _widgetsList.add(Text('LargePhoto:', style: _textStyleBold));
        _widgetsList.add(
          GestureDetector(
            child: Text('${InstaParser.profileInstance.posts[i]['photoLargeSize']}\n', style: _textStyleUrl,),
            onLongPress: () {
              Clipboard.setData(new ClipboardData(text: '${InstaParser.profileInstance.posts[i]['photoLargeSize']}'));
              key.currentState.showSnackBar(SnackBar(content: new Text("Copied large size photo url")));
            }
          )
        );

        _widgetsList.add(Text('Video:', style: _textStyleBold));
        _widgetsList.add(
          GestureDetector(
            child: Text('${InstaParser.profileInstance.posts[i]['videoUrl']}\n', style: _textStyleUrl,),
            onLongPress: () {
              Clipboard.setData(new ClipboardData(text: '${InstaParser.profileInstance.posts[i]['videoUrl']}'));
              key.currentState.showSnackBar(SnackBar(content: new Text("Copied video url")));
            }
          )
        );

        _widgetsList.add(Container(padding: EdgeInsets.only(top: 8.0, bottom: 8.0), child: Divider(height: 0.0, color: Colors.black)));
      }
      return _widgetsList;
    }

    return MaterialApp(
      color: Colors.blue,
      title: 'InstaParser',
      home: Scaffold(
        key: key,
        backgroundColor: Colors.purple[100],
        appBar: AppBar(title: Text('InstaParser'), backgroundColor: Colors.purple[600],),
        body: Center(
          child: ListView(
            children: [
              
              Container( // Profile text field
                padding: EdgeInsets.only(left: 16.0, right: 16.0, top: 16.0, bottom: 16.0),
                child: Form(
                  child: TextFormField(
                    controller: _textEditingController,
                    decoration: InputDecoration(
                      contentPadding: EdgeInsets.only(top: 2.0, bottom: 2.0),
                      labelText: 'Profile URL', 
                      labelStyle: _textStyleUrl,
                      hintText: 'https://www.instagram.com/kevin/',
                      hintStyle: TextStyle(color: Colors.grey[500], fontSize: 13))))),

              Container(
                padding: EdgeInsets.only(left: 64.0, right: 64.0, bottom: 16.0),
                child: RaisedButton( // Submit button
                  child: Text('Parse', style: _textStyleUrl,),
                  onPressed: () async {
                    InstaParser.parseProfile('${_textEditingController.text}', rebuild).then((onValue) {
                      setState(() {});
                    });                     
                  },
                ),
              ),

              Container(
                padding: EdgeInsets.only(left: 16.0, right: 16.0, bottom: 16.0),
                child: InstaParser.profileInstance != null
                ? Column(
                  crossAxisAlignment: CrossAxisAlignment.start,
                  mainAxisSize: MainAxisSize.min,
                  children: _buildPostData(InstaParser.profileInstance),
                )
                : Container(),
              ),
            ]
          ),
        ) ,
      )
    );
  }

}

